summaryrefslogtreecommitdiffstats
path: root/lib/interfaces/extensions
diff options
context:
space:
mode:
Diffstat (limited to 'lib/interfaces/extensions')
-rw-r--r--lib/interfaces/extensions/CMakeLists.txt20
-rw-r--r--lib/interfaces/extensions/Mainpage.dox10
-rw-r--r--lib/interfaces/extensions/Makefile.am18
-rw-r--r--lib/interfaces/extensions/codebrowserfrontend.h8
-rw-r--r--lib/interfaces/extensions/dcop/CMakeLists.txt10
-rw-r--r--lib/interfaces/extensions/dcop/Makefile.am10
-rw-r--r--lib/interfaces/extensions/dcop/TDevAppFrontendIface.cpp (renamed from lib/interfaces/extensions/dcop/KDevAppFrontendIface.cpp)26
-rw-r--r--lib/interfaces/extensions/dcop/TDevAppFrontendIface.h (renamed from lib/interfaces/extensions/dcop/KDevAppFrontendIface.h)14
-rw-r--r--lib/interfaces/extensions/dcop/TDevMakeFrontendIface.cpp (renamed from lib/interfaces/extensions/dcop/KDevMakeFrontendIface.cpp)14
-rw-r--r--lib/interfaces/extensions/dcop/TDevMakeFrontendIface.h (renamed from lib/interfaces/extensions/dcop/KDevMakeFrontendIface.h)14
-rw-r--r--lib/interfaces/extensions/kdevappfrontend.cpp2
-rw-r--r--lib/interfaces/extensions/kdevmakefrontend.cpp2
-rw-r--r--lib/interfaces/extensions/tdevappfrontend.cpp2
-rw-r--r--lib/interfaces/extensions/tdevappfrontend.h (renamed from lib/interfaces/extensions/kdevappfrontend.h)20
-rw-r--r--lib/interfaces/extensions/tdevcreatefile.h (renamed from lib/interfaces/extensions/kdevcreatefile.h)22
-rw-r--r--lib/interfaces/extensions/tdevdifffrontend.cpp (renamed from lib/interfaces/extensions/kdevdifffrontend.cpp)10
-rw-r--r--lib/interfaces/extensions/tdevdifffrontend.h (renamed from lib/interfaces/extensions/kdevdifffrontend.h)20
-rw-r--r--lib/interfaces/extensions/tdevmakefrontend.cpp2
-rw-r--r--lib/interfaces/extensions/tdevmakefrontend.h (renamed from lib/interfaces/extensions/kdevmakefrontend.h)20
-rw-r--r--lib/interfaces/extensions/tdevquickopen.h (renamed from lib/interfaces/extensions/kdevquickopen.h)36
-rw-r--r--lib/interfaces/extensions/tdevsourceformatter.h (renamed from lib/interfaces/extensions/kdevsourceformatter.h)18
-rw-r--r--lib/interfaces/extensions/tdevversioncontrol.h (renamed from lib/interfaces/extensions/kdevversioncontrol.h)36
22 files changed, 167 insertions, 167 deletions
diff --git a/lib/interfaces/extensions/CMakeLists.txt b/lib/interfaces/extensions/CMakeLists.txt
index 459c1197..cf5514be 100644
--- a/lib/interfaces/extensions/CMakeLists.txt
+++ b/lib/interfaces/extensions/CMakeLists.txt
@@ -22,9 +22,9 @@ include_directories(
##### headers ###################################
install( FILES
- codebrowserfrontend.h kdevappfrontend.h kdevcreatefile.h
- kdevdifffrontend.h kdevmakefrontend.h kdevquickopen.h
- kdevsourceformatter.h kdevversioncontrol.h
+ codebrowserfrontend.h tdevappfrontend.h tdevcreatefile.h
+ tdevdifffrontend.h tdevmakefrontend.h tdevquickopen.h
+ tdevsourceformatter.h tdevversioncontrol.h
DESTINATION ${INCLUDE_INSTALL_DIR}/tdevelop/interfaces/extensions )
install( FILES
@@ -35,20 +35,20 @@ install( FILES
DESTINATION ${SERVICETYPES_INSTALL_DIR} )
-##### kdevextensions (static) ###################
+##### tdevextensions (static) ###################
add_custom_command( OUTPUT codebrowserfrontend.moc.cpp
COMMAND
${TMOC_EXECUTABLE} ${CMAKE_CURRENT_SOURCE_DIR}/codebrowserfrontend.h -o codebrowserfrontend.moc.cpp
DEPENDS ${CMAKE_CURRENT_SOURCE_DIR}/codebrowserfrontend.h )
-add_custom_command( OUTPUT kdevversioncontrol.moc.cpp
+add_custom_command( OUTPUT tdevversioncontrol.moc.cpp
COMMAND
- ${TMOC_EXECUTABLE} ${CMAKE_CURRENT_SOURCE_DIR}/kdevversioncontrol.h -o kdevversioncontrol.moc.cpp
- DEPENDS ${CMAKE_CURRENT_SOURCE_DIR}/kdevversioncontrol.h )
+ ${TMOC_EXECUTABLE} ${CMAKE_CURRENT_SOURCE_DIR}/tdevversioncontrol.h -o tdevversioncontrol.moc.cpp
+ DEPENDS ${CMAKE_CURRENT_SOURCE_DIR}/tdevversioncontrol.h )
-tde_add_library( kdevextensions STATIC_PIC AUTOMOC
+tde_add_library( tdevextensions STATIC_PIC AUTOMOC
SOURCES
- kdevappfrontend.cpp kdevappfrontend.cpp kdevmakefrontend.cpp
- codebrowserfrontend.moc.cpp kdevversioncontrol.moc.cpp
+ tdevappfrontend.cpp tdevappfrontend.cpp tdevmakefrontend.cpp
+ codebrowserfrontend.moc.cpp tdevversioncontrol.moc.cpp
)
diff --git a/lib/interfaces/extensions/Mainpage.dox b/lib/interfaces/extensions/Mainpage.dox
index 3b493fde..37c72c16 100644
--- a/lib/interfaces/extensions/Mainpage.dox
+++ b/lib/interfaces/extensions/Mainpage.dox
@@ -10,8 +10,8 @@ This library contains extension interfaces used by TDevelop plugin architecture.
\section whatisextension What is the TDevelop extension
Extension is a TDevelop plugin which implements one of extension interfaces.
-Extension is usually not important enough to be returned by @ref KDevApi and @ref KDevPlugin
-methods. Therefore extension instance can be obtained by @ref KDevPlugin::extension method.
+Extension is usually not important enough to be returned by @ref TDevApi and @ref TDevPlugin
+methods. Therefore extension instance can be obtained by @ref TDevPlugin::extension method.
Note: extension plugins can be either core, global and project plugins. They are loaded
in the same way other plugins are. But extensions differ from usual plugins.
@@ -36,10 +36,10 @@ those should be loaded at a time. This can be accomplished by:
@endcode
- Define an abstract base class for an extension like:
@code
- class KDevMyExtension: public KDevPlugin {
+ class KDevMyExtension: public TDevPlugin {
public:
- KDevMyExtension(const KDevPluginInfo *info, QObject* parent, const char* name)
- :KDevPlugin(info, parent, name) {}
+ KDevMyExtension(const TDevPluginInfo *info, QObject* parent, const char* name)
+ :TDevPlugin(info, parent, name) {}
virtual void doSomething() = 0;
};
diff --git a/lib/interfaces/extensions/Makefile.am b/lib/interfaces/extensions/Makefile.am
index a6d00bc2..55f4d774 100644
--- a/lib/interfaces/extensions/Makefile.am
+++ b/lib/interfaces/extensions/Makefile.am
@@ -1,7 +1,7 @@
tdevelopincludeextdir = $(includedir)/tdevelop/interfaces/extensions
-tdevelopincludeext_HEADERS = codebrowserfrontend.h kdevappfrontend.h \
- kdevcreatefile.h kdevdifffrontend.h kdevmakefrontend.h kdevquickopen.h \
- kdevsourceformatter.h kdevversioncontrol.h
+tdevelopincludeext_HEADERS = codebrowserfrontend.h tdevappfrontend.h \
+ tdevcreatefile.h tdevdifffrontend.h tdevmakefrontend.h tdevquickopen.h \
+ tdevsourceformatter.h tdevversioncontrol.h
servicetypedir = $(kde_servicetypesdir)
servicetype_DATA = tdevelopappfrontend.desktop \
@@ -10,14 +10,14 @@ servicetype_DATA = tdevelopappfrontend.desktop \
tdevelopversioncontrol.desktop
SUBDIRS = dcop
-libkdevextensions_la_LDFLAGS = $(all_libraries)
-noinst_LTLIBRARIES = libkdevextensions.la
-libkdevextensions_la_SOURCES = kdevappfrontend.cpp kdevmakefrontend.cpp
+libtdevextensions_la_LDFLAGS = $(all_libraries)
+noinst_LTLIBRARIES = libtdevextensions.la
+libtdevextensions_la_SOURCES = tdevappfrontend.cpp tdevmakefrontend.cpp
INCLUDES = -I$(top_srcdir)/lib/interfaces $(all_includes)
METASOURCES = AUTO
-DOXYGEN_REFERENCES = dcop interfaces tdecore tdefx tdeui tdehtml tdemdi tdeio kjs tdeparts tdeutils kdevinterfaces
-DOXYGEN_PROJECTNAME = KDevelop Extension Interfaces Library
-DOXYGEN_DOCDIRPREFIX = kdev
+DOXYGEN_REFERENCES = dcop interfaces tdecore tdefx tdeui tdehtml tdemdi tdeio kjs tdeparts tdeutils tdevinterfaces
+DOXYGEN_PROJECTNAME = TDevelop Extension Interfaces Library
+DOXYGEN_DOCDIRPREFIX = tdev
include ../../../Doxyfile.am
noinst_HEADERS = codebrowserfrontend.h
diff --git a/lib/interfaces/extensions/codebrowserfrontend.h b/lib/interfaces/extensions/codebrowserfrontend.h
index e8158fe4..68c4e90f 100644
--- a/lib/interfaces/extensions/codebrowserfrontend.h
+++ b/lib/interfaces/extensions/codebrowserfrontend.h
@@ -20,18 +20,18 @@
#define CODEBROWSERRONTEND_H
-#include <kdevplugin.h>
+#include <tdevplugin.h>
#include <codemodel.h>
namespace Extensions {
-class KDevCodeBrowserFrontend : public KDevPlugin {
+class TDevCodeBrowserFrontend : public TDevPlugin {
Q_OBJECT
public:
- KDevCodeBrowserFrontend(const KDevPluginInfo *info, TQObject *parent=0, const char *name=0 )
- :KDevPlugin(info, parent, name ? name : "CodeBrowserFrontend") {}
+ TDevCodeBrowserFrontend(const TDevPluginInfo *info, TQObject *parent=0, const char *name=0 )
+ :TDevPlugin(info, parent, name ? name : "CodeBrowserFrontend") {}
///Used by the quickopen-plugin to notify extensions that it jumped to a searched item
virtual bool jumpedToItem( ItemDom item ) = 0;
diff --git a/lib/interfaces/extensions/dcop/CMakeLists.txt b/lib/interfaces/extensions/dcop/CMakeLists.txt
index b6255fc6..8658d320 100644
--- a/lib/interfaces/extensions/dcop/CMakeLists.txt
+++ b/lib/interfaces/extensions/dcop/CMakeLists.txt
@@ -21,14 +21,14 @@ include_directories(
##### headers ###################################
install( FILES
- KDevAppFrontendIface.h KDevMakeFrontendIface.h
+ TDevAppFrontendIface.h TDevMakeFrontendIface.h
DESTINATION ${INCLUDE_INSTALL_DIR}/tdevelop/interfaces/extensions/dcop )
-##### kdevdcopextensions (static) ###############
+##### tdevdcopextensions (static) ###############
-tde_add_library( kdevdcopextensions STATIC_PIC
+tde_add_library( tdevdcopextensions STATIC_PIC
SOURCES
- KDevAppFrontendIface.cpp KDevMakeFrontendIface.cpp
- KDevAppFrontendIface.skel KDevMakeFrontendIface.skel
+ TDevAppFrontendIface.cpp TDevMakeFrontendIface.cpp
+ TDevAppFrontendIface.skel TDevMakeFrontendIface.skel
)
diff --git a/lib/interfaces/extensions/dcop/Makefile.am b/lib/interfaces/extensions/dcop/Makefile.am
index 116c4979..e46606ac 100644
--- a/lib/interfaces/extensions/dcop/Makefile.am
+++ b/lib/interfaces/extensions/dcop/Makefile.am
@@ -1,10 +1,10 @@
INCLUDES = -I$(top_srcdir)/lib/interfaces -I$(top_srcdir)/lib/interfaces/extensions $(all_includes)
METASOURCES = AUTO
-noinst_LTLIBRARIES = libkdevdcopextensions.la
-libkdevdcopextensions_la_LDFLAGS = $(all_libraries)
-libkdevdcopextensions_la_SOURCES = KDevAppFrontendIface.cpp \
- KDevMakeFrontendIface.cpp KDevAppFrontendIface.skel KDevMakeFrontendIface.skel
+noinst_LTLIBRARIES = libtdevdcopextensions.la
+libtdevdcopextensions_la_LDFLAGS = $(all_libraries)
+libtdevdcopextensions_la_SOURCES = TDevAppFrontendIface.cpp \
+ TDevMakeFrontendIface.cpp TDevAppFrontendIface.skel TDevMakeFrontendIface.skel
dcopincludeextdir = $(includedir)/tdevelop/interfaces/extensions/dcop
-dcopincludeext_HEADERS = KDevAppFrontendIface.h KDevMakeFrontendIface.h
+dcopincludeext_HEADERS = TDevAppFrontendIface.h TDevMakeFrontendIface.h
diff --git a/lib/interfaces/extensions/dcop/KDevAppFrontendIface.cpp b/lib/interfaces/extensions/dcop/TDevAppFrontendIface.cpp
index 1eca4bfc..a42d0d7d 100644
--- a/lib/interfaces/extensions/dcop/KDevAppFrontendIface.cpp
+++ b/lib/interfaces/extensions/dcop/TDevAppFrontendIface.cpp
@@ -21,56 +21,56 @@
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/
-#include "KDevAppFrontendIface.h"
-#include "kdevappfrontend.h"
+#include "TDevAppFrontendIface.h"
+#include "tdevappfrontend.h"
-KDevAppFrontendIface::KDevAppFrontendIface(KDevAppFrontend *appFrontend)
- : DCOPObject("KDevAppFrontend"), m_appFrontend(appFrontend)
+TDevAppFrontendIface::TDevAppFrontendIface(TDevAppFrontend *appFrontend)
+ : DCOPObject("TDevAppFrontend"), m_appFrontend(appFrontend)
{
}
-KDevAppFrontendIface::~KDevAppFrontendIface()
+TDevAppFrontendIface::~TDevAppFrontendIface()
{}
-void KDevAppFrontendIface::startAppCommand(const TQString &directory, const TQString &command, bool inTerminal)
+void TDevAppFrontendIface::startAppCommand(const TQString &directory, const TQString &command, bool inTerminal)
{
m_appFrontend->startAppCommand(directory, command, inTerminal);
}
-void KDevAppFrontendIface::stopApplication( )
+void TDevAppFrontendIface::stopApplication( )
{
m_appFrontend->stopApplication();
}
-bool KDevAppFrontendIface::isRunning( )
+bool TDevAppFrontendIface::isRunning( )
{
return m_appFrontend->isRunning();
}
-void KDevAppFrontendIface::clearView( )
+void TDevAppFrontendIface::clearView( )
{
m_appFrontend->clearView();
}
-void KDevAppFrontendIface::insertStderrLine( const TQCString & line )
+void TDevAppFrontendIface::insertStderrLine( const TQCString & line )
{
m_appFrontend->insertStderrLine(line);
}
-void KDevAppFrontendIface::insertStdoutLine( const TQCString & line )
+void TDevAppFrontendIface::insertStdoutLine( const TQCString & line )
{
m_appFrontend->insertStdoutLine(line);
}
-void KDevAppFrontendIface::addPartialStderrLine( const TQCString& line )
+void TDevAppFrontendIface::addPartialStderrLine( const TQCString& line )
{
m_appFrontend->addPartialStderrLine(line);
}
-void KDevAppFrontendIface::addPartialStdoutLine( const TQCString& line )
+void TDevAppFrontendIface::addPartialStdoutLine( const TQCString& line )
{
m_appFrontend->addPartialStdoutLine(line);
}
diff --git a/lib/interfaces/extensions/dcop/KDevAppFrontendIface.h b/lib/interfaces/extensions/dcop/TDevAppFrontendIface.h
index 3903e897..5061c782 100644
--- a/lib/interfaces/extensions/dcop/KDevAppFrontendIface.h
+++ b/lib/interfaces/extensions/dcop/TDevAppFrontendIface.h
@@ -19,21 +19,21 @@
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/
-#ifndef _KDEVAPPFRONTENDIFACE_H_
-#define _KDEVAPPFRONTENDIFACE_H_
+#ifndef _TDEVAPPFRONTENDIFACE_H_
+#define _TDEVAPPFRONTENDIFACE_H_
#include <dcopobject.h>
-class KDevAppFrontend;
+class TDevAppFrontend;
-class KDevAppFrontendIface : public DCOPObject
+class TDevAppFrontendIface : public DCOPObject
{
K_DCOP
public:
- KDevAppFrontendIface( KDevAppFrontend *appFrontend );
- ~KDevAppFrontendIface();
+ TDevAppFrontendIface( TDevAppFrontend *appFrontend );
+ ~TDevAppFrontendIface();
k_dcop:
void startAppCommand(const TQString &directory, const TQString &command, bool inTerminal);
@@ -46,7 +46,7 @@ k_dcop:
void addPartialStdoutLine(const TQCString &line);
private:
- KDevAppFrontend *m_appFrontend;
+ TDevAppFrontend *m_appFrontend;
};
#endif
diff --git a/lib/interfaces/extensions/dcop/KDevMakeFrontendIface.cpp b/lib/interfaces/extensions/dcop/TDevMakeFrontendIface.cpp
index 73305e4a..06bd432f 100644
--- a/lib/interfaces/extensions/dcop/KDevMakeFrontendIface.cpp
+++ b/lib/interfaces/extensions/dcop/TDevMakeFrontendIface.cpp
@@ -20,27 +20,27 @@
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/
-#include "KDevMakeFrontendIface.h"
-#include "kdevmakefrontend.h"
+#include "TDevMakeFrontendIface.h"
+#include "tdevmakefrontend.h"
-KDevMakeFrontendIface::KDevMakeFrontendIface(KDevMakeFrontend *makeFrontend)
- : DCOPObject("KDevMakeFrontend")
+TDevMakeFrontendIface::TDevMakeFrontendIface(TDevMakeFrontend *makeFrontend)
+ : DCOPObject("TDevMakeFrontend")
{
m_makeFrontend = makeFrontend;
}
-KDevMakeFrontendIface::~KDevMakeFrontendIface()
+TDevMakeFrontendIface::~TDevMakeFrontendIface()
{}
-void KDevMakeFrontendIface::queueCommand(const TQString &dir, const TQString &command)
+void TDevMakeFrontendIface::queueCommand(const TQString &dir, const TQString &command)
{
m_makeFrontend->queueCommand(dir, command);
}
-bool KDevMakeFrontendIface::isRunning( )
+bool TDevMakeFrontendIface::isRunning( )
{
return m_makeFrontend->isRunning();
}
diff --git a/lib/interfaces/extensions/dcop/KDevMakeFrontendIface.h b/lib/interfaces/extensions/dcop/TDevMakeFrontendIface.h
index 53217359..3aee75be 100644
--- a/lib/interfaces/extensions/dcop/KDevMakeFrontendIface.h
+++ b/lib/interfaces/extensions/dcop/TDevMakeFrontendIface.h
@@ -18,28 +18,28 @@
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/
-#ifndef _KDEVMAKEFRONTENDIFACE_H_
-#define _KDEVMAKEFRONTENDIFACE_H_
+#ifndef _TDEVMAKEFRONTENDIFACE_H_
+#define _TDEVMAKEFRONTENDIFACE_H_
#include <dcopobject.h>
-class KDevMakeFrontend;
+class TDevMakeFrontend;
-class KDevMakeFrontendIface : public DCOPObject
+class TDevMakeFrontendIface : public DCOPObject
{
K_DCOP
public:
- KDevMakeFrontendIface( KDevMakeFrontend *makeFrontend );
- ~KDevMakeFrontendIface();
+ TDevMakeFrontendIface( TDevMakeFrontend *makeFrontend );
+ ~TDevMakeFrontendIface();
k_dcop:
void queueCommand(const TQString &dir, const TQString &command);
bool isRunning();
private:
- KDevMakeFrontend *m_makeFrontend;
+ TDevMakeFrontend *m_makeFrontend;
};
#endif
diff --git a/lib/interfaces/extensions/kdevappfrontend.cpp b/lib/interfaces/extensions/kdevappfrontend.cpp
deleted file mode 100644
index 3d918fe2..00000000
--- a/lib/interfaces/extensions/kdevappfrontend.cpp
+++ /dev/null
@@ -1,2 +0,0 @@
-#include "kdevappfrontend.h"
-#include "kdevappfrontend.moc"
diff --git a/lib/interfaces/extensions/kdevmakefrontend.cpp b/lib/interfaces/extensions/kdevmakefrontend.cpp
deleted file mode 100644
index 5e035270..00000000
--- a/lib/interfaces/extensions/kdevmakefrontend.cpp
+++ /dev/null
@@ -1,2 +0,0 @@
-#include "kdevmakefrontend.h"
-#include "kdevmakefrontend.moc"
diff --git a/lib/interfaces/extensions/tdevappfrontend.cpp b/lib/interfaces/extensions/tdevappfrontend.cpp
new file mode 100644
index 00000000..4f7c52a7
--- /dev/null
+++ b/lib/interfaces/extensions/tdevappfrontend.cpp
@@ -0,0 +1,2 @@
+#include "tdevappfrontend.h"
+#include "tdevappfrontend.moc"
diff --git a/lib/interfaces/extensions/kdevappfrontend.h b/lib/interfaces/extensions/tdevappfrontend.h
index 76952f35..085d3c9d 100644
--- a/lib/interfaces/extensions/kdevappfrontend.h
+++ b/lib/interfaces/extensions/tdevappfrontend.h
@@ -23,14 +23,14 @@
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/
-#ifndef KDEVAPPFRONTEND_H
-#define KDEVAPPFRONTEND_H
+#ifndef TDEVAPPFRONTEND_H
+#define TDEVAPPFRONTEND_H
#include <tqstringlist.h>
-#include <kdevplugin.h>
+#include <tdevplugin.h>
/**
-@file kdevappfrontend.h
+@file tdevappfrontend.h
Application frontend interface.
*/
@@ -45,16 +45,16 @@ Currently, this interface defines ways to do the following:
Instances that implement this interface are available through extension architecture:
@code
-KDevAppFrontend *apf = extension<KDevAppFrontend>("TDevelop/AppFrontend");
+TDevAppFrontend *apf = extension<TDevAppFrontend>("TDevelop/AppFrontend");
if (apf) {
// do something
} else {
// fail
}
@endcode
-@sa KDevPlugin::extension method documentation.
+@sa TDevPlugin::extension method documentation.
*/
-class KDevAppFrontend : public KDevPlugin
+class TDevAppFrontend : public TDevPlugin
{
Q_OBJECT
@@ -66,11 +66,11 @@ public:
plugin information in various places like "about application" dialog, plugin selector
dialog, etc. Plugin does not take ownership on info object, also its lifetime should
be equal to the lifetime of the plugin.
- @param parent The parent object for the plugin. Parent object must implement @ref KDevApi
+ @param parent The parent object for the plugin. Parent object must implement @ref TDevApi
interface. Otherwise the plugin will not be constructed.
@param name The internal name which identifies the plugin.*/
- KDevAppFrontend(const KDevPluginInfo *info, TQObject *parent=0, const char *name=0 )
- :KDevPlugin(info, parent, name ? name : "KDevAppFrontend") {}
+ TDevAppFrontend(const TDevPluginInfo *info, TQObject *parent=0, const char *name=0 )
+ :TDevPlugin(info, parent, name ? name : "TDevAppFrontend") {}
/**@return Whether the application is currently running.*/
virtual bool isRunning() = 0;
diff --git a/lib/interfaces/extensions/kdevdifffrontend.cpp b/lib/interfaces/extensions/tdevdifffrontend.cpp
index 745703e4..aa7e0b19 100644
--- a/lib/interfaces/extensions/kdevdifffrontend.cpp
+++ b/lib/interfaces/extensions/tdevdifffrontend.cpp
@@ -18,16 +18,16 @@
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/
-#include "kdevdifffrontend.h"
+#include "tdevdifffrontend.h"
-KDevDiffFrontend::KDevDiffFrontend(const KDevPluginInfo *info, TQObject *parent, const char *name)
- : KDevPlugin(info, parent, name ? name : "KDevDiffFrontend")
+TDevDiffFrontend::TDevDiffFrontend(const TDevPluginInfo *info, TQObject *parent, const char *name)
+ : TDevPlugin(info, parent, name ? name : "TDevDiffFrontend")
{
}
-KDevDiffFrontend::~KDevDiffFrontend()
+TDevDiffFrontend::~TDevDiffFrontend()
{
}
-#include "kdevdifffrontend.moc"
+#include "tdevdifffrontend.moc"
diff --git a/lib/interfaces/extensions/kdevdifffrontend.h b/lib/interfaces/extensions/tdevdifffrontend.h
index 6d4cb2b6..c0c343cb 100644
--- a/lib/interfaces/extensions/kdevdifffrontend.h
+++ b/lib/interfaces/extensions/tdevdifffrontend.h
@@ -18,14 +18,14 @@
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/
-#ifndef KDEVDIFFFRONTEND_H
-#define KDEVDIFFFRONTEND_H
+#ifndef TDEVDIFFFRONTEND_H
+#define TDEVDIFFFRONTEND_H
#include <kurl.h>
-#include <kdevplugin.h>
+#include <tdevplugin.h>
/**
-@file kdevdifffrontend.h
+@file tdevdifffrontend.h
Diff frontend interface.
*/
@@ -36,16 +36,16 @@ files.
Instances that implement this interface are available through extension architecture:
@code
-KDevDiffFrontend *df = extension<KDevDiffFrontend>("TDevelop/DiffFrontend");
+TDevDiffFrontend *df = extension<TDevDiffFrontend>("TDevelop/DiffFrontend");
if (df) {
// do something
} else {
// fail
}
@endcode
-@sa KDevPlugin::extension method documentation.
+@sa TDevPlugin::extension method documentation.
*/
-class KDevDiffFrontend : public KDevPlugin
+class TDevDiffFrontend : public TDevPlugin
{
public:
@@ -55,11 +55,11 @@ public:
plugin information in various places like "about application" dialog, plugin selector
dialog, etc. Plugin does not take ownership on info object, also its lifetime should
be equal to the lifetime of the plugin.
- @param parent The parent object for the plugin. Parent object must implement @ref KDevApi
+ @param parent The parent object for the plugin. Parent object must implement @ref TDevApi
interface. Otherwise the plugin will not be constructed.
@param name The internal name which identifies the plugin.*/
- KDevDiffFrontend( const KDevPluginInfo *info, TQObject *parent=0, const char *name=0 )
- :KDevPlugin(info, parent, name ? name : "KDevDiffFrontend") {}
+ TDevDiffFrontend( const TDevPluginInfo *info, TQObject *parent=0, const char *name=0 )
+ :TDevPlugin(info, parent, name ? name : "TDevDiffFrontend") {}
/**Displays the patch.
@param diff A string which contains a patch in unified format.*/
diff --git a/lib/interfaces/extensions/tdevmakefrontend.cpp b/lib/interfaces/extensions/tdevmakefrontend.cpp
new file mode 100644
index 00000000..140d074d
--- /dev/null
+++ b/lib/interfaces/extensions/tdevmakefrontend.cpp
@@ -0,0 +1,2 @@
+#include "tdevmakefrontend.h"
+#include "tdevmakefrontend.moc"
diff --git a/lib/interfaces/extensions/kdevmakefrontend.h b/lib/interfaces/extensions/tdevmakefrontend.h
index 52afa3d3..47b14fc4 100644
--- a/lib/interfaces/extensions/kdevmakefrontend.h
+++ b/lib/interfaces/extensions/tdevmakefrontend.h
@@ -23,14 +23,14 @@
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/
-#ifndef KDEVMAKEFRONTEND_H
-#define KDEVMAKEFRONTEND_H
+#ifndef TDEVMAKEFRONTEND_H
+#define TDEVMAKEFRONTEND_H
#include <tqstringlist.h>
-#include <kdevplugin.h>
+#include <tdevplugin.h>
/**
-@file kdevmakefrontend.h
+@file tdevmakefrontend.h
Make frontend interface.
*/
@@ -41,16 +41,16 @@ or similar commands to build a project, api documentation, etc.
Instances that implement this interface are available through extension architecture:
@code
-KDevMakeFrontend *mf = extension<KDevMakeFrontend>("TDevelop/MakeFrontend");
+TDevMakeFrontend *mf = extension<TDevMakeFrontend>("TDevelop/MakeFrontend");
if (mf) {
// do something
} else {
// fail
}
@endcode
-@sa KDevPlugin::extension method documentation.
+@sa TDevPlugin::extension method documentation.
*/
-class KDevMakeFrontend : public KDevPlugin
+class TDevMakeFrontend : public TDevPlugin
{
Q_OBJECT
@@ -63,11 +63,11 @@ public:
plugin information in various places like "about application" dialog, plugin selector
dialog, etc. Plugin does not take ownership on info object, also its lifetime should
be equal to the lifetime of the plugin.
- @param parent The parent object for the plugin. Parent object must implement @ref KDevApi
+ @param parent The parent object for the plugin. Parent object must implement @ref TDevApi
interface. Otherwise the plugin will not be constructed.
@param name The internal name which identifies the plugin.*/
- KDevMakeFrontend(const KDevPluginInfo *info, TQObject *parent=0, const char *name=0 )
- :KDevPlugin(info, parent, name ? name : "KDevMakeFrontend") {}
+ TDevMakeFrontend(const TDevPluginInfo *info, TQObject *parent=0, const char *name=0 )
+ :TDevPlugin(info, parent, name ? name : "TDevMakeFrontend") {}
/**@return The widget where the make output is shown.*/
virtual TQWidget* widget() { return 0L; }
diff --git a/lib/interfaces/extensions/kdevquickopen.h b/lib/interfaces/extensions/tdevquickopen.h
index 91dce7ca..e1fd2f65 100644
--- a/lib/interfaces/extensions/kdevquickopen.h
+++ b/lib/interfaces/extensions/tdevquickopen.h
@@ -16,14 +16,14 @@
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/
-#ifndef KDEVQUICKOPEN_H
-#define KDEVQUICKOPEN_H
+#ifndef TDEVQUICKOPEN_H
+#define TDEVQUICKOPEN_H
-#include <kdevplugin.h>
+#include <tdevplugin.h>
#include <kurl.h>
/**
-@file kdevquickopen.h
+@file tdevquickopen.h
Source formatter interface.
*/
@@ -39,10 +39,10 @@ if (qo) {
// fail
}
@endcode
-@sa @ref KDevPlugin::extension method documentation.
+@sa @ref TDevPlugin::extension method documentation.
@sa @ref whatisextension and @ref creatingextension sections of Platform API documentation.
*/
-class KDevQuickOpen : public KDevPlugin
+class KDevQuickOpen : public TDevPlugin
{
public:
/**Constructor.
@@ -51,11 +51,11 @@ public:
plugin information in various places like "about application" dialog, plugin selector
dialog, etc. Plugin does not take ownership on info object, also its lifetime should
be equal to the lifetime of the plugin.
- @param parent The parent object for the plugin. Parent object must implement @ref KDevApi
+ @param parent The parent object for the plugin. Parent object must implement @ref TDevApi
interface. Otherwise the plugin will not be constructed.
@param name The internal name which identifies the plugin.*/
- KDevQuickOpen(const KDevPluginInfo *info, TQObject* parent, const char* name)
- :KDevPlugin(info, parent, name) {}
+ KDevQuickOpen(const TDevPluginInfo *info, TQObject* parent, const char* name)
+ :TDevPlugin(info, parent, name) {}
/**Shows the file selection dialog.
@param text A list of urls to open.*/
@@ -81,14 +81,14 @@ public:
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/
-#ifndef KDEVQUICKOPEN_H
-#define KDEVQUICKOPEN_H
+#ifndef TDEVQUICKOPEN_H
+#define TDEVQUICKOPEN_H
-#include <kdevplugin.h>
+#include <tdevplugin.h>
#include <kurl.h>
/**
-@file kdevquickopen.h
+@file tdevquickopen.h
Source formatter interface.
*/
@@ -104,10 +104,10 @@ if (qo) {
// fail
}
@endcode
-@sa @ref KDevPlugin::extension method documentation.
+@sa @ref TDevPlugin::extension method documentation.
@sa @ref whatisextension and @ref creatingextension sections of Platform API documentation.
*/
-class KDevQuickOpen : public KDevPlugin
+class KDevQuickOpen : public TDevPlugin
{
public:
/**Constructor.
@@ -116,11 +116,11 @@ public:
plugin information in various places like "about application" dialog, plugin selector
dialog, etc. Plugin does not take ownership on info object, also its lifetime should
be equal to the lifetime of the plugin.
- @param parent The parent object for the plugin. Parent object must implement @ref KDevApi
+ @param parent The parent object for the plugin. Parent object must implement @ref TDevApi
interface. Otherwise the plugin will not be constructed.
@param name The internal name which identifies the plugin.*/
- KDevQuickOpen(const KDevPluginInfo *info, TQObject* parent, const char* name)
- :KDevPlugin(info, parent, name) {}
+ KDevQuickOpen(const TDevPluginInfo *info, TQObject* parent, const char* name)
+ :TDevPlugin(info, parent, name) {}
/**Shows the file selection dialog.
@param text A list of urls to open.*/
diff --git a/lib/interfaces/extensions/kdevsourceformatter.h b/lib/interfaces/extensions/tdevsourceformatter.h
index c4a380cf..3403a5d2 100644
--- a/lib/interfaces/extensions/kdevsourceformatter.h
+++ b/lib/interfaces/extensions/tdevsourceformatter.h
@@ -16,13 +16,13 @@
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/
-#ifndef KDEVSOURCEFORMATTER_H
-#define KDEVSOURCEFORMATTER_H
+#ifndef TDEVSOURCEFORMATTER_H
+#define TDEVSOURCEFORMATTER_H
-#include <kdevplugin.h>
+#include <tdevplugin.h>
/**
-@file kdevsourceformatter.h
+@file tdevsourceformatter.h
Source formatter interface.
*/
@@ -39,10 +39,10 @@ if (sf) {
// fail
}
@endcode
-@sa @ref KDevPlugin::extension method documentation.
+@sa @ref TDevPlugin::extension method documentation.
@sa @ref whatisextension and @ref creatingextension sections of Platform API documentation.
*/
-class KDevSourceFormatter : public KDevPlugin
+class KDevSourceFormatter : public TDevPlugin
{
public:
/**Constructor.
@@ -51,11 +51,11 @@ public:
plugin information in various places like "about application" dialog, plugin selector
dialog, etc. Plugin does not take ownership on info object, also its lifetime should
be equal to the lifetime of the plugin.
- @param parent The parent object for the plugin. Parent object must implement @ref KDevApi
+ @param parent The parent object for the plugin. Parent object must implement @ref TDevApi
interface. Otherwise the plugin will not be constructed.
@param name The internal name which identifies the plugin.*/
- KDevSourceFormatter(const KDevPluginInfo *info, TQObject* parent, const char* name)
- :KDevPlugin(info, parent, name) {}
+ KDevSourceFormatter(const TDevPluginInfo *info, TQObject* parent, const char* name)
+ :TDevPlugin(info, parent, name) {}
/**Formats the source.
@param text A string with a code.
diff --git a/lib/interfaces/extensions/kdevversioncontrol.h b/lib/interfaces/extensions/tdevversioncontrol.h
index a19c6275..d796e31f 100644
--- a/lib/interfaces/extensions/kdevversioncontrol.h
+++ b/lib/interfaces/extensions/tdevversioncontrol.h
@@ -20,8 +20,8 @@
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/
-#ifndef KDEVVERSIONCONTROL_H
-#define KDEVVERSIONCONTROL_H
+#ifndef TDEVVERSIONCONTROL_H
+#define TDEVVERSIONCONTROL_H
#include <tqobject.h>
#include <tqstring.h>
@@ -29,10 +29,10 @@
#include <tqmap.h>
#include <tqvaluelist.h>
-#include <kdevplugin.h>
+#include <tdevplugin.h>
/**
-@file kdevversioncontrol.h
+@file tdevversioncontrol.h
Version control system interface and utility classes.
*/
@@ -112,7 +112,7 @@ This is a type definition: @code TQMap<TQString,VCSFileInfo> VCSFileInfoMap; @en
*/
typedef TQMap<TQString,VCSFileInfo> VCSFileInfoMap;
-class KDevVCSFileInfoProvider;
+class TDevVCSFileInfoProvider;
/**
@@ -123,16 +123,16 @@ VCS support plugins should implement this interface.
Instances that implement this interface are available through extension architecture:
@code
-KDevVersionControl *vcs = extension<KDevVersionControl>("TDevelop/VersionControl");
+TDevVersionControl *vcs = extension<TDevVersionControl>("TDevelop/VersionControl");
if (vcs) {
// do something
} else {
// fail
}
@endcode
-@sa KDevPlugin::extension method documentation.
+@sa TDevPlugin::extension method documentation.
*/
-class KDevVersionControl: public KDevPlugin
+class TDevVersionControl: public TDevPlugin
{
Q_OBJECT
@@ -144,11 +144,11 @@ public:
plugin information in various places like "about application" dialog, plugin selector
dialog, etc. Plugin does not take ownership on info object, also its lifetime should
be equal to the lifetime of the plugin.
- @param parent The parent object for the plugin. Parent object must implement @ref KDevApi
+ @param parent The parent object for the plugin. Parent object must implement @ref TDevApi
interface. Otherwise the plugin will not be constructed.
@param name The internal name which identifies the plugin.*/
- KDevVersionControl(const KDevPluginInfo *info, TQObject *parent, const char *name )
- :KDevPlugin(info, parent, name ) {}
+ TDevVersionControl(const TDevPluginInfo *info, TQObject *parent, const char *name )
+ :TDevPlugin(info, parent, name ) {}
/**Creates a new project in the passed path @p dir. This should instantiate
VCS infrastructure and import a project into the VCS in that directory.
@@ -161,7 +161,7 @@ public:
virtual bool fetchFromRepository() = 0;
/**@return The file info provider for this version control (0 if none is available).*/
- virtual KDevVCSFileInfoProvider *fileInfoProvider() const = 0;
+ virtual TDevVCSFileInfoProvider *fileInfoProvider() const = 0;
/**Checks if the directory is valid for this version control (for example
CVS may check for the presence of "<dirPath>/CVS/" subdir and something else)
@@ -182,7 +182,7 @@ signals:
/**
Basic interface for providing info on file registered in a version control repository repository.
*/
-class KDevVCSFileInfoProvider: public TQObject
+class TDevVCSFileInfoProvider: public TQObject
{
Q_OBJECT
@@ -190,7 +190,7 @@ public:
/**Constructor.
@param parent The parent VCS plugin.
@param name The name of a provider object.*/
- KDevVCSFileInfoProvider(KDevVersionControl *parent, const char *name)
+ TDevVCSFileInfoProvider(TDevVersionControl *parent, const char *name)
: TQObject( parent, name ), m_owner(parent) {}
/**Gets the status for local files in the specified directory:
@@ -226,14 +226,14 @@ signals:
protected:
/**@return The version control which owns this provider.*/
- KDevVersionControl *owner() const { return m_owner; }
+ TDevVersionControl *owner() const { return m_owner; }
private:
- KDevVersionControl *m_owner;
+ TDevVersionControl *m_owner;
private:
- KDevVCSFileInfoProvider( const KDevVCSFileInfoProvider & );
- KDevVCSFileInfoProvider &operator=( const KDevVCSFileInfoProvider & );
+ TDevVCSFileInfoProvider( const TDevVCSFileInfoProvider & );
+ TDevVCSFileInfoProvider &operator=( const TDevVCSFileInfoProvider & );
};
#endif
diff --git a/lib/interfaces/extensions/kdevcreatefile.h b/lib/interfaces/extensions/tdevcreatefile.h
index 35b98d19..b1148e94 100644
--- a/lib/interfaces/extensions/kdevcreatefile.h
+++ b/lib/interfaces/extensions/tdevcreatefile.h
@@ -17,15 +17,15 @@
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.
*/
-#ifndef KDEVCREATEFILE_H
-#define KDEVCREATEFILE_H
+#ifndef TDEVCREATEFILE_H
+#define TDEVCREATEFILE_H
#include <tqstring.h>
-#include <kdevplugin.h>
+#include <tdevplugin.h>
/**
-@file kdevcreatefile.h
+@file tdevcreatefile.h
File creation facility interface.
*/
@@ -36,20 +36,20 @@ An abstract class for all extensions that are responsible for file creation.
Instances that implement this interface are available through extension architecture:
@code
-KDevCreateFile *cf = extension<KDevCreateFile>("TDevelop/CreateFile");
+TDevCreateFile *cf = extension<TDevCreateFile>("TDevelop/CreateFile");
if (cf) {
// do something
} else {
// fail
}
@endcode
-@sa KDevPlugin::extension method documentation.
+@sa TDevPlugin::extension method documentation.
*/
-class KDevCreateFile : public KDevPlugin
+class TDevCreateFile : public TDevPlugin
{
public:
/**File created with @ref KDevCreateFile implementation.*/
class CreatedFile {
public:
@@ -119,11 +119,11 @@ public:
plugin information in various places like "about application" dialog, plugin selector
dialog, etc. Plugin does not take ownership on info object, also its lifetime should
be equal to the lifetime of the plugin.
- @param parent The parent object for the plugin. Parent object must implement @ref KDevApi
+ @param parent The parent object for the plugin. Parent object must implement @ref TDevApi
interface. Otherwise the plugin will not be constructed.
@param name The internal name which identifies the plugin.*/
- KDevCreateFile(const KDevPluginInfo *info, TQObject * parent = 0, const char * name = 0)
- :KDevPlugin(info, parent, name) {}
+ TDevCreateFile(const TDevPluginInfo *info, TQObject * parent = 0, const char * name = 0)
+ :TDevPlugin(info, parent, name) {}
/**Creates a new file, within or without the project.
Supply as much information as you know. Leave what you don't know as TQString().
@@ -36,20 +36,20 @@ An abstract class for all extensions that are responsible for file creation.
{
public:
- /**File created with @ref KDevCreateFile implementation.*/
+ /**File created with @ref TDevCreateFile implementation.*/
class CreatedFile {
public: